==> peaceful-progression-1.1.0-sources.jar: xen42/peacefulitems/mixin/PandaEntityMixin.java <==
package xen42.peacefulitems.mixin;

import java.util.Random;
import net.minecraft.class_1440;
import net.minecraft.class_1802;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_3417;
import net.minecraft.class_3532;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1440.class)
public class PandaEntityMixin {
	private static final Random random = new Random();

    @Inject(at = @At("HEAD"), method = "sneeze", cancellable = true)
	private void sneeze(CallbackInfo info) {
		var panda = ((class_1440)(Object)this);

        var nosePos = new class_243(
            panda.method_23317() - (panda.method_6109() ? 1.0 : 1.3) * (double)(panda.method_17681() + 1.0f) * 0.5 * (double)class_3532.method_15374(panda.field_6283 * ((float)Math.PI / 180)), 
            panda.method_23320() - (panda.method_6109() ? 0.1 : 0.3), 
            panda.method_23321() + (panda.method_6109() ? 1.0 : 1.3) * (double)(panda.method_17681() + 1.0f) * 0.5 * (double)class_3532.method_15362(panda.field_6283 * ((float)Math.PI / 180)));

        // Base game pandas have a 1 in 700 chance of dropping slime
        // Bump that up to 3 (technically theres a 1 in 2100 chance now that they drop two at once)
        // Also make it spawn near their face
        if (!panda.method_37908().method_8608() && random.nextInt(3) == 0) {
            var item = panda.method_5706(class_1802.field_8777);
            item.method_33574(nosePos);
            // Play a sound so you know it happened
            panda.method_5783(class_3417.field_15219, 1.0f, (random.nextFloat() - random.nextFloat()) * 0.2f + 1.0f);
        }

        // For adult pandas we pitch shift down the sound so we will just call the method stuff ourselves
        // We will also skip the part where all other pandas jump
        if (!panda.method_6109()) {
            panda.method_5783(class_3417.field_15076, 1.0f, 0.7f);
            var vel = panda.method_18798();
            panda.method_37908().method_8406(class_2398.field_11234, nosePos.field_1352, nosePos.field_1351, nosePos.field_1350, vel.field_1352, 0.0, vel.field_1350);
        
            info.cancel();
        }
	}
}

==> peaceful-progression-1.1.1-sources.jar: xen42/peacefulitems/mixin/PandaEntityMixin.java <==
package xen42.peacefulitems.mixin;

import java.util.Random;
import net.minecraft.class_1440;
import net.minecraft.class_1802;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3532;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1440.class)
public class PandaEntityMixin {
	private static final Random random = new Random();

    @Inject(at = @At("HEAD"), method = "sneeze", cancellable = true)
	private void sneeze(CallbackInfo info) {
		var panda = ((class_1440)(Object)this);

        var nosePos = new class_243(
            panda.method_23317() - (panda.method_6109() ? 1.0 : 1.3) * (double)(panda.method_17681() + 1.0f) * 0.5 * (double)class_3532.method_15374(panda.field_6283 * ((float)Math.PI / 180)), 
            panda.method_23320() - (panda.method_6109() ? 0.1 : 0.3), 
            panda.method_23321() + (panda.method_6109() ? 1.0 : 1.3) * (double)(panda.method_17681() + 1.0f) * 0.5 * (double)class_3532.method_15362(panda.field_6283 * ((float)Math.PI / 180)));

        // Base game pandas have a 1 in 700 chance of dropping slime
        // Bump that up to 3 (technically theres a 1 in 2100 chance now that they drop two at once)
        // Also make it spawn near their face
        if (!panda.method_73183().method_8608() && random.nextInt(3) == 0) {
            var item = panda.method_5706((class_3218)panda.method_73183(), class_1802.field_8777);
            item.method_33574(nosePos);
            // Play a sound so you know it happened
            panda.method_5783(class_3417.field_15219, 1.0f, (random.nextFloat() - random.nextFloat()) * 0.2f + 1.0f);
        }

        // For adult pandas we pitch shift down the sound so we will just call the method stuff ourselves
        // We will also skip the part where all other pandas jump
        if (!panda.method_6109()) {
            panda.method_5783(class_3417.field_15076, 1.0f, 0.7f);
            var vel = panda.method_18798();
            panda.method_73183().method_8406(class_2398.field_11234, nosePos.field_1352, nosePos.field_1351, nosePos.field_1350, vel.field_1352, 0.0, vel.field_1350);
        
            info.cancel();
        }
	}
}
